@@ -30,8 +30,17 @@ class Stack:
 		else:
 			return False
 
+	def is_full(self):
+		if len(self.items) > 1:
+			return True
+		else:
+			return False
+
 	def is_empty(self):
-		return self.top == -1
+		if self.top < 1:
+			return True
+		else:
+			return False
 
 	def procedure_push(self, item):
 		self.top = self.top + 1
@@ -41,7 +50,7 @@ class Stack:
 
 	def procedure_pop(self):
 		if self.is_empty():
-			raise IndexError("Stack is empty")
+			raise IndexError("Stack is empty.")
 		item = self.array[self.top]
 		self.top = self.top - 1
 		return item
@@ -49,12 +58,12 @@ class Stack:
 	def procedure_peek(self):
 		"""Check the top-most element of the stack."""
 		if self.is_empty():
-			raise IndexError("Stack is empty")
+			raise IndexError("Stack is empty.")
 		return self.array[self.top]
 
 	def procedure_expand_size(self):
 		"""Expands size of the stack using : 0(n)"""
-		self.array = self.array + [None] * len(self.array)
+		return len(self.array)
 
 class Node:
 	"""
@@ -84,8 +93,17 @@ class LinkedList:
 			yield probe.data
 			probe = probe.next
 
+	def is_full(self):
+		if len(self.top) > 1:
+			return True
+		else:
+			return False
+
 	def is_empty(self):
-		return self.top == -1
+		if self.top < 1:
+			return True
+		else:
+			return False
 
 	def procedure_push(self, data):
 		node = Node(data)
@@ -95,7 +113,7 @@ class LinkedList:
 
 	def procedure_pop(self):
 		if self.is_empty():
-			raise IndexError("Stack is empty")
+			raise IndexError("Stack is empty, set a value first.")
 		data = self.head.data
 		self.head = self.head.next
 		self.top = self.top - 1
@@ -103,5 +121,19 @@ class LinkedList:
 
 	def procedure_peek(self):
 		if self.is_empty():
-			raise IndexError("Stack is empty")
-		return self.head.data
\ No newline at end of file
+			raise IndexError("Stack is empty, you either must be popped or not set a value.")
+		return self.head.data
+
+class BalancedParenthesis:
+
+    def is_balanced(parenthesis):
+        """Use Stack class to checking valid parenthesis."""
+        stack = Stack(len(parenthesis))
+        for ps in parenthesis:
+            if ps == "(":
+                stack.procedure_push(ps)
+            elif ps == ")":
+                if stack.is_empty():
+                    return "Stack is unbalanced."
+                stack.procedure_pop()
+        return stack.is_empty()
